clophfit.prtecan
----------------

.. automodule:: clophfit.prtecan
   :special-members: __almost_eq__


..
   .. autoclass:: Titration
      :show-inheritance:

..
   .. autoclass:: Tecanfile
	  :exclude-members: path
